function [residual, g1, g2, g3] = first_one_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           columns: equations in order of declaration
%                                                           rows: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(8, 1);
T40 = y(1)^params(4);
T44 = (y(4)*exp(y(5)))^(1-params(4));
T75 = exp(y(5))*getPowerDeriv(y(4)*exp(y(5)),1-params(4),1);
T83 = y(4)*exp(y(5))*getPowerDeriv(y(4)*exp(y(5)),1-params(4),1);
lhs =1/y(7);
rhs =params(1)*1/y(11)*(1+y(12)-params(3));
residual(1)= lhs-rhs;
lhs =y(7)*params(2)/(1-y(4));
rhs =y(9);
residual(2)= lhs-rhs;
lhs =y(7)+y(8);
rhs =y(6);
residual(3)= lhs-rhs;
lhs =y(5);
rhs =params(5)*y(2)+x(it_, 1);
residual(4)= lhs-rhs;
lhs =y(6);
rhs =T40*T44;
residual(5)= lhs-rhs;
lhs =y(9);
rhs =(1-params(4))*y(6)*(params(7)-1)/params(7)/y(4);
residual(6)= lhs-rhs;
lhs =y(10);
rhs =params(4)*y(6)*(params(7)-1)/params(7)/y(1);
residual(7)= lhs-rhs;
lhs =y(8);
rhs =y(3)-y(1)*(1-params(3));
residual(8)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(8, 13);

  %
  % Jacobian matrix
  %

  g1(1,7)=(-1)/(y(7)*y(7));
  g1(1,11)=(-((1+y(12)-params(3))*params(1)*(-1)/(y(11)*y(11))));
  g1(1,12)=(-(params(1)*1/y(11)));
  g1(2,4)=y(7)*params(2)/((1-y(4))*(1-y(4)));
  g1(2,7)=params(2)/(1-y(4));
  g1(2,9)=(-1);
  g1(3,6)=(-1);
  g1(3,7)=1;
  g1(3,8)=1;
  g1(4,2)=(-params(5));
  g1(4,5)=1;
  g1(4,13)=(-1);
  g1(5,1)=(-(T44*getPowerDeriv(y(1),params(4),1)));
  g1(5,4)=(-(T40*T75));
  g1(5,5)=(-(T40*T83));
  g1(5,6)=1;
  g1(6,4)=(-((-((1-params(4))*y(6)*(params(7)-1)/params(7)))/(y(4)*y(4))));
  g1(6,6)=(-((1-params(4))*(params(7)-1)/params(7)/y(4)));
  g1(6,9)=1;
  g1(7,1)=(-((-(params(4)*y(6)*(params(7)-1)/params(7)))/(y(1)*y(1))));
  g1(7,6)=(-(params(4)*(params(7)-1)/params(7)/y(1)));
  g1(7,10)=1;
  g1(8,1)=1-params(3);
  g1(8,3)=(-1);
  g1(8,8)=1;
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(22,3);
  v2(1,1)=1;
  v2(1,2)=85;
  v2(1,3)=(y(7)+y(7))/(y(7)*y(7)*y(7)*y(7));
  v2(2,1)=1;
  v2(2,2)=141;
  v2(2,3)=(-((1+y(12)-params(3))*params(1)*(y(11)+y(11))/(y(11)*y(11)*y(11)*y(11))));
  v2(3,1)=1;
  v2(3,2)=154;
  v2(3,3)=(-(params(1)*(-1)/(y(11)*y(11))));
  v2(4,1)=1;
  v2(4,2)=142;
  v2(4,3)=  v2(3,3);
  v2(5,1)=2;
  v2(5,2)=43;
  v2(5,3)=(-(y(7)*params(2)*((-(1-y(4)))-(1-y(4)))))/((1-y(4))*(1-y(4))*(1-y(4))*(1-y(4)));
  v2(6,1)=2;
  v2(6,2)=82;
  v2(6,3)=params(2)/((1-y(4))*(1-y(4)));
  v2(7,1)=2;
  v2(7,2)=46;
  v2(7,3)=  v2(6,3);
  v2(8,1)=5;
  v2(8,2)=1;
  v2(8,3)=(-(T44*getPowerDeriv(y(1),params(4),2)));
  v2(9,1)=5;
  v2(9,2)=40;
  v2(9,3)=(-(getPowerDeriv(y(1),params(4),1)*T75));
  v2(10,1)=5;
  v2(10,2)=4;
  v2(10,3)=  v2(9,3);
  v2(11,1)=5;
  v2(11,2)=43;
  v2(11,3)=(-(T40*exp(y(5))*exp(y(5))*getPowerDeriv(y(4)*exp(y(5)),1-params(4),2)));
  v2(12,1)=5;
  v2(12,2)=53;
  v2(12,3)=(-(getPowerDeriv(y(1),params(4),1)*T83));
  v2(13,1)=5;
  v2(13,2)=5;
  v2(13,3)=  v2(12,3);
  v2(14,1)=5;
  v2(14,2)=56;
  v2(14,3)=(-(T40*(T75+y(4)*exp(y(5))*exp(y(5))*getPowerDeriv(y(4)*exp(y(5)),1-params(4),2))));
  v2(15,1)=5;
  v2(15,2)=44;
  v2(15,3)=  v2(14,3);
  v2(16,1)=5;
  v2(16,2)=57;
  v2(16,3)=(-(T40*(T83+y(4)*exp(y(5))*y(4)*exp(y(5))*getPowerDeriv(y(4)*exp(y(5)),1-params(4),2))));
  v2(17,1)=6;
  v2(17,2)=43;
  v2(17,3)=(-((-((-((1-params(4))*y(6)*(params(7)-1)/params(7)))*(y(4)+y(4))))/(y(4)*y(4)*y(4)*y(4))));
  v2(18,1)=6;
  v2(18,2)=69;
  v2(18,3)=(-((-((1-params(4))*(params(7)-1)/params(7)))/(y(4)*y(4))));
  v2(19,1)=6;
  v2(19,2)=45;
  v2(19,3)=  v2(18,3);
  v2(20,1)=7;
  v2(20,2)=1;
  v2(20,3)=(-((-((-(params(4)*y(6)*(params(7)-1)/params(7)))*(y(1)+y(1))))/(y(1)*y(1)*y(1)*y(1))));
  v2(21,1)=7;
  v2(21,2)=66;
  v2(21,3)=(-((-(params(4)*(params(7)-1)/params(7)))/(y(1)*y(1))));
  v2(22,1)=7;
  v2(22,2)=6;
  v2(22,3)=  v2(21,3);
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),8,169);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],8,2197);
end
end
