function [residual, g1, g2] = first_one_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                    columns: equations in order of declaration
%                                                    rows: variables in declaration order
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: equations in order of declaration
%                                                       rows: variables in declaration order
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 8, 1);

%
% Model equations
%

lhs =1/y(5);
rhs =1/y(5)*params(1)*(1+y(8)-params(3));
residual(1)= lhs-rhs;
lhs =y(5)*params(2)/(1-y(2));
rhs =y(7);
residual(2)= lhs-rhs;
lhs =y(5)+y(6);
rhs =y(4);
residual(3)= lhs-rhs;
lhs =y(3);
rhs =y(3)*params(5)+x(1);
residual(4)= lhs-rhs;
lhs =y(4);
rhs =y(1)^params(4)*(y(2)*exp(y(3)))^(1-params(4));
residual(5)= lhs-rhs;
lhs =y(7);
rhs =(1-params(4))*y(4)*(params(7)-1)/params(7)/y(2);
residual(6)= lhs-rhs;
lhs =y(8);
rhs =params(4)*y(4)*(params(7)-1)/params(7)/y(1);
residual(7)= lhs-rhs;
lhs =y(6);
rhs =y(1)-y(1)*(1-params(3));
residual(8)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(8, 8);

  %
  % Jacobian matrix
  %

  g1(1,5)=(-1)/(y(5)*y(5))-(1+y(8)-params(3))*params(1)*(-1)/(y(5)*y(5));
  g1(1,8)=(-(1/y(5)*params(1)));
  g1(2,2)=y(5)*params(2)/((1-y(2))*(1-y(2)));
  g1(2,5)=params(2)/(1-y(2));
  g1(2,7)=(-1);
  g1(3,4)=(-1);
  g1(3,5)=1;
  g1(3,6)=1;
  g1(4,3)=1-params(5);
  g1(5,1)=(-((y(2)*exp(y(3)))^(1-params(4))*getPowerDeriv(y(1),params(4),1)));
  g1(5,2)=(-(y(1)^params(4)*exp(y(3))*getPowerDeriv(y(2)*exp(y(3)),1-params(4),1)));
  g1(5,3)=(-(y(1)^params(4)*y(2)*exp(y(3))*getPowerDeriv(y(2)*exp(y(3)),1-params(4),1)));
  g1(5,4)=1;
  g1(6,2)=(-((-((1-params(4))*y(4)*(params(7)-1)/params(7)))/(y(2)*y(2))));
  g1(6,4)=(-((1-params(4))*(params(7)-1)/params(7)/y(2)));
  g1(6,7)=1;
  g1(7,1)=(-((-(params(4)*y(4)*(params(7)-1)/params(7)))/(y(1)*y(1))));
  g1(7,4)=(-(params(4)*(params(7)-1)/params(7)/y(1)));
  g1(7,8)=1;
  g1(8,1)=(-(1-(1-params(3))));
  g1(8,6)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],8,64);
end
end
